@@ -1,17 +1,18 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
+/* exported AppSwitcherPopup, GroupCyclerPopup, WindowSwitcherPopup,
+            WindowCyclerPopup */
 
 const { Atk, Clutter, Gio, GLib, GObject, Meta, Shell, St } = imports.gi;
 const Mainloop = imports.mainloop;
 
 const Main = imports.ui.main;
 const SwitcherPopup = imports.ui.switcherPopup;
-const Tweener = imports.ui.tweener;
 
 var APP_ICON_HOVER_TIMEOUT = 200; // milliseconds
 
 var THUMBNAIL_DEFAULT_SIZE = 256;
 var THUMBNAIL_POPUP_TIME = 500; // milliseconds
-var THUMBNAIL_FADE_TIME = 0.1; // seconds
+var THUMBNAIL_FADE_TIME = 100; // milliseconds
 
 var WINDOW_PREVIEW_SIZE = 128;
 var APP_ICON_SIZE = 96;
@@ -87,9 +88,9 @@ class AppSwitcherPopup extends SwitcherPopup.SwitcherPopup {
             let hPadding = leftPadding + rightPadding;
 
             let icon = this._items[this._selectedIndex];
-            let [posX, posY] = icon.get_transformed_position();
+            let [posX] = icon.get_transformed_position();
             let thumbnailCenter = posX + icon.width / 2;
-            let [childMinWidth, childNaturalWidth] = this._thumbnails.get_preferred_width(-1);
+            let [, childNaturalWidth] = this._thumbnails.get_preferred_width(-1);
             childBox.x1 = Math.max(primary.x + leftPadding, Math.floor(thumbnailCenter - childNaturalWidth / 2));
             if (childBox.x1 + childNaturalWidth > primary.x + primary.width - hPadding) {
                 let offset = childBox.x1 + childNaturalWidth - primary.width + hPadding;
@@ -103,7 +104,7 @@ class AppSwitcherPopup extends SwitcherPopup.SwitcherPopup {
                 childBox.x2 = primary.x + primary.width - rightPadding;
             childBox.y1 = this._switcherList.allocation.y2 + spacing;
             this._thumbnails.addClones(primary.y + primary.height - bottomPadding - childBox.y1);
-            let [childMinHeight, childNaturalHeight] = this._thumbnails.get_preferred_height(-1);
+            let [, childNaturalHeight] = this._thumbnails.get_preferred_height(-1);
             childBox.y2 = childBox.y1 + childNaturalHeight;
             this._thumbnails.allocate(childBox, flags);
         }
@@ -360,15 +361,15 @@ class AppSwitcherPopup extends SwitcherPopup.SwitcherPopup {
 
     _destroyThumbnails() {
         let thumbnailsActor = this._thumbnails;
-        Tweener.addTween(thumbnailsActor,
-                         { opacity: 0,
-                           time: THUMBNAIL_FADE_TIME,
-                           transition: 'easeOutQuad',
-                           onComplete: () => {
-                               thumbnailsActor.destroy();
-                               this.thumbnailsVisible = false;
-                           }
-                         });
+        this._thumbnails.ease({
+            opacity: 0,
+            duration: THUMBNAIL_FADE_TIME,
+            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+            onComplete: () => {
+                thumbnailsActor.destroy();
+                this.thumbnailsVisible = false;
+            }
+        });
         this._thumbnails = null;
         if (this._switcherList._items[this._selectedIndex])
             this._switcherList._items[this._selectedIndex].remove_accessible_state (Atk.StateType.EXPANDED);
@@ -391,12 +392,14 @@ class AppSwitcherPopup extends SwitcherPopup.SwitcherPopup {
         this._thumbnails.get_allocation_box();
 
         this._thumbnails.opacity = 0;
-        Tweener.addTween(this._thumbnails,
-                         { opacity: 255,
-                           time: THUMBNAIL_FADE_TIME,
-                           transition: 'easeOutQuad',
-                           onComplete: () => this.thumbnailsVisible = true
-                         });
+        this._thumbnails.ease({
+            opacity: 255,
+            duration: THUMBNAIL_FADE_TIME,
+            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+            onComplete: () => {
+                this.thumbnailsVisible = true;
+            }
+        });
 
         this._switcherList._items[this._selectedIndex].add_accessible_state (Atk.StateType.EXPANDED);
     }
@@ -469,7 +472,7 @@ var CyclerList = GObject.registerClass({
                'item-removed': { param_types: [GObject.TYPE_INT] },
                'item-highlighted': { param_types: [GObject.TYPE_INT] } },
 }, class CyclerList extends St.Widget {
-    highlight(index, justOutline) {
+    highlight(index, _justOutline) {
         this.emit('item-highlighted', index);
     }
 });
@@ -494,7 +497,7 @@ var CyclerPopup = GObject.registerClass({
         });
     }
 
-    _highlightItem(index, justOutline) {
+    _highlightItem(index, _justOutline) {
         this._highlight.window = this._items[index];
         global.window_group.set_child_above_sibling(this._highlight.actor, null);
     }
@@ -660,6 +663,7 @@ class AppIcon extends St.BoxLayout {
         this.add(this.label, { x_fill: false });
     }
 
+    // eslint-disable-next-line camelcase
     set_size(size) {
         this.icon = this.app.create_icon_texture(size);
         this._iconBin.child = this.icon;
@@ -801,7 +805,7 @@ class AppSwitcher extends SwitcherPopup.SwitcherList {
     }
 
     _enterItem(index) {
-        let [x, y, mask] = global.get_pointer();
+        let [x, y] = global.get_pointer();
         let pickedActor = global.stage.get_actor_at_pos(Clutter.PickMode.ALL, x, y);
         if (this._items[index].contains(pickedActor))
             this._itemEntered(index);
@@ -908,7 +912,7 @@ class ThumbnailList extends SwitcherPopup.SwitcherList {
             return;
         let totalPadding = this._items[0].get_theme_node().get_horizontal_padding() + this._items[0].get_theme_node().get_vertical_padding();
         totalPadding += this.get_theme_node().get_horizontal_padding() + this.get_theme_node().get_vertical_padding();
-        let [labelMinHeight, labelNaturalHeight] = this._labels[0].get_preferred_height(-1);
+        let [, labelNaturalHeight] = this._labels[0].get_preferred_height(-1);
         let spacing = this._items[0].child.get_theme_node().get_length('spacing');
         let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
         let thumbnailSize = THUMBNAIL_DEFAULT_SIZE * scaleFactor;
