@@ -1,4 +1,5 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
+/* exported LocatePointer */
 
 const { Gio } = imports.gi;
 const Ripples = imports.ui.ripples;
@@ -18,7 +19,7 @@ var LocatePointer = class {
         if (!this._settings.get_boolean(LOCATE_POINTER_KEY))
             return;
 
-        let [x, y, mods] = global.get_pointer();
+        let [x, y] = global.get_pointer();
         this._ripples.playAnimation(x, y);
     }
 };
