@@ -1,4 +1,5 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
+/* exported SessionMode, listModes */
 
 const GLib = imports.gi.GLib;
 const Mainloop = imports.mainloop;
@@ -114,9 +115,9 @@ function _loadMode(file, info) {
     if (_modes.hasOwnProperty(modeName))
         return;
 
-    let fileContent, success, tag, newMode;
+    let fileContent, success_, newMode;
     try {
-        [success, fileContent, tag] = file.load_contents(null);
+        [success_, fileContent] = file.load_contents(null);
         if (fileContent instanceof Uint8Array)
             fileContent = imports.byteArray.toString(fileContent);
         newMode = JSON.parse(fileContent);
