@@ -1102,12 +1102,10 @@ main (int    argc,
 static void __attribute__((format(printf, 1, 0)))
 print_debug (const gchar *format, ...)
 {
-  gchar *s;
+  g_autofree char *s = NULL;
+  g_autofree char *timestamp = NULL;
   va_list ap;
-  gchar timebuf[64];
-  GTimeVal now;
-  time_t now_t;
-  struct tm broken_down;
+  g_autoptr (GDateTime) now = NULL;
   static volatile gsize once_init_value = 0;
   static gboolean show_debug = FALSE;
   static guint pid = 0;
@@ -1122,17 +1120,15 @@ print_debug (const gchar *format, ...)
   if (!show_debug)
     goto out;
 
-  g_get_current_time (&now);
-  now_t = now.tv_sec;
-  localtime_r (&now_t, &broken_down);
-  strftime (timebuf, sizeof timebuf, "%H:%M:%S", &broken_down);
+  now = g_date_time_new_now_local ();
+  timestamp = g_date_time_format (now, "%H:%M:%S");
 
   va_start (ap, format);
   s = g_strdup_vprintf (format, ap);
   va_end (ap);
 
-  g_print ("gnome-shell-calendar-server[%d]: %s.%03d: %s\n", pid, timebuf, (gint) (now.tv_usec / 1000), s);
-  g_free (s);
+  g_print ("gnome-shell-calendar-server[%d]: %s.%03d: %s\n",
+           pid, timestamp, g_date_time_get_microsecond (now), s);
  out:
   ;
 }
