@@ -39,9 +39,13 @@ enum
   PROP_GICON,
   PROP_ICON_NAME,
   PROP_ICON_SIZE,
-  PROP_FALLBACK_ICON_NAME
+  PROP_FALLBACK_ICON_NAME,
+
+  N_PROPS
 };
 
+static GParamSpec *props[N_PROPS] = { NULL, };
+
 struct _StIconPrivate
 {
   ClutterActor *icon_texture;
@@ -210,11 +214,15 @@ st_icon_style_changed (StWidget *widget)
   st_icon_update (self);
 }
 
+static void
+st_icon_resource_scale_changed (StWidget *widget)
+{
+  st_icon_update (ST_ICON (widget));
+}
+
 static void
 st_icon_class_init (StIconClass *klass)
 {
-  GParamSpec *pspec;
-
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   ClutterActorClass *actor_class = CLUTTER_ACTOR_CLASS (klass);
   StWidgetClass *widget_class = ST_WIDGET_CLASS (klass);
@@ -226,32 +234,37 @@ st_icon_class_init (StIconClass *klass)
   actor_class->paint = st_icon_paint;
 
   widget_class->style_changed = st_icon_style_changed;
+  widget_class->resource_scale_changed = st_icon_resource_scale_changed;
 
-  pspec = g_param_spec_object ("gicon",
-                               "GIcon",
-                               "The GIcon shown by this icon actor",
-                               G_TYPE_ICON,
-                               ST_PARAM_READWRITE);
-  g_object_class_install_property (object_class, PROP_GICON, pspec);
+  props[PROP_GICON] =
+    g_param_spec_object ("gicon",
+                         "GIcon",
+                         "The GIcon shown by this icon actor",
+                         G_TYPE_ICON,
+                         ST_PARAM_READWRITE);
 
-  pspec = g_param_spec_string ("icon-name",
-                               "Icon name",
-                               "An icon name",
-                               NULL, ST_PARAM_READWRITE);
-  g_object_class_install_property (object_class, PROP_ICON_NAME, pspec);
+  props[PROP_ICON_NAME] =
+    g_param_spec_string ("icon-name",
+                         "Icon name",
+                         "An icon name",
+                         NULL,
+                         ST_PARAM_READWRITE);
 
-  pspec = g_param_spec_int ("icon-size",
-                            "Icon size",
-                            "The size if the icon, if positive. Otherwise the size will be derived from the current style",
-                            -1, G_MAXINT, -1,
-                            ST_PARAM_READWRITE);
-  g_object_class_install_property (object_class, PROP_ICON_SIZE, pspec);
+  props[PROP_ICON_SIZE] =
+    g_param_spec_int ("icon-size",
+                      "Icon size",
+                      "The size if the icon, if positive. Otherwise the size will be derived from the current style",
+                      -1, G_MAXINT, -1,
+                      ST_PARAM_READWRITE);
 
-  pspec = g_param_spec_string ("fallback-icon-name",
-                               "Fallback icon name",
-                               "A fallback icon name",
-                               NULL, ST_PARAM_READWRITE);
-  g_object_class_install_property (object_class, PROP_FALLBACK_ICON_NAME, pspec);
+  props[PROP_FALLBACK_ICON_NAME] =
+    g_param_spec_string ("fallback-icon-name",
+                         "Fallback icon name",
+                         "A fallback icon name",
+                         NULL,
+                         ST_PARAM_READWRITE);
+
+  g_object_class_install_properties (object_class, N_PROPS, props);
 }
 
 static void
@@ -344,6 +357,8 @@ st_icon_finish_update (StIcon *icon)
       g_signal_connect_object (priv->icon_texture, "notify::content",
                                G_CALLBACK (on_content_changed), icon, 0);
     }
+
+  clutter_actor_queue_relayout (CLUTTER_ACTOR (icon));
 }
 
 static void
@@ -366,9 +381,10 @@ st_icon_update (StIcon *icon)
   StIconPrivate *priv = icon->priv;
   StThemeNode *theme_node;
   StTextureCache *cache;
-  gint scale;
+  gint paint_scale;
   ClutterActor *stage;
   StThemeContext *context;
+  float resource_scale;
 
   if (priv->pending_texture)
     {
@@ -378,13 +394,16 @@ st_icon_update (StIcon *icon)
       priv->opacity_handler_id = 0;
     }
 
+  if (!st_widget_get_resource_scale (ST_WIDGET (icon), &resource_scale))
+    return;
+
   theme_node = st_widget_peek_theme_node (ST_WIDGET (icon));
   if (theme_node == NULL)
     return;
 
   stage = clutter_actor_get_stage (CLUTTER_ACTOR (icon));
   context = st_theme_context_get_for_stage (CLUTTER_STAGE (stage));
-  g_object_get (context, "scale-factor", &scale, NULL);
+  g_object_get (context, "scale-factor", &paint_scale, NULL);
 
   cache = st_texture_cache_get_default ();
 
@@ -393,14 +412,16 @@ st_icon_update (StIcon *icon)
                                                          theme_node,
                                                          priv->gicon,
                                                          priv->icon_size,
-                                                         scale);
+                                                         paint_scale,
+                                                         resource_scale);
 
   if (priv->pending_texture == NULL && priv->fallback_gicon != NULL)
     priv->pending_texture = st_texture_cache_load_gicon (cache,
                                                          theme_node,
                                                          priv->fallback_gicon,
                                                          priv->icon_size,
-                                                         scale);
+                                                         paint_scale,
+                                                         resource_scale);
 
   if (priv->pending_texture)
     {
@@ -513,8 +534,8 @@ st_icon_set_icon_name (StIcon      *icon,
 
   priv->gicon = gicon;
 
-  g_object_notify (G_OBJECT (icon), "gicon");
-  g_object_notify (G_OBJECT (icon), "icon-name");
+  g_object_notify_by_pspec (G_OBJECT (icon), props[PROP_GICON]);
+  g_object_notify_by_pspec (G_OBJECT (icon), props[PROP_ICON_NAME]);
 
   g_object_thaw_notify (G_OBJECT (icon));
 
@@ -558,7 +579,7 @@ st_icon_set_gicon (StIcon *icon, GIcon *gicon)
   if (gicon)
     icon->priv->gicon = g_object_ref (gicon);
 
-  g_object_notify (G_OBJECT (icon), "gicon");
+  g_object_notify_by_pspec (G_OBJECT (icon), props[PROP_GICON]);
 
   st_icon_update (icon);
 }
@@ -602,7 +623,7 @@ st_icon_set_icon_size (StIcon *icon,
       priv->prop_icon_size = size;
       if (st_icon_update_icon_size (icon))
         st_icon_update (icon);
-      g_object_notify (G_OBJECT (icon), "icon-size");
+      g_object_notify_by_pspec (G_OBJECT (icon), props[PROP_ICON_SIZE]);
     }
 }
 
@@ -645,7 +666,7 @@ st_icon_set_fallback_icon_name (StIcon      *icon,
 
   priv->fallback_gicon = gicon;
 
-  g_object_notify (G_OBJECT (icon), "fallback-icon-name");
+  g_object_notify_by_pspec (G_OBJECT (icon), props[PROP_FALLBACK_ICON_NAME]);
 
   st_icon_update (icon);
 }
