@@ -143,8 +143,6 @@ gboolean              st_widget_get_resource_scale        (StWidget        *widg
 
 /* debug methods */
 char  *st_describe_actor       (ClutterActor *actor);
-void   st_set_slow_down_factor (gfloat factor);
-gfloat st_get_slow_down_factor (void);
 
 /* accessibility methods */
 void                  st_widget_set_accessible_role      (StWidget    *widget,
